@@ -261,7 +261,7 @@ class Table(metaclass=MetaTable):
                     if 'options' in config and (isinstance(value, list) or isinstance(value, tuple) or isinstance(value, set)):
                         fields.append(cls.name+'."'+column+"\" IN ("+','.join(['%s'] * len(value))+")")
                         for item in value:
-                            #log.debug(color.cyan('%s'), item)
+                            log.debug(color.cyan('%s'), item)
                             values.append(cls.value(field, item))
                     elif (config['type'] == 'int' or
                         config['type'] == 'date' or
@@ -382,7 +382,7 @@ class Table(metaclass=MetaTable):
                     name = config['field']
                 else:
                     name = field
-                fields.append(name)
+                fields.append(ESCAPE+name+ESCAPE)
 
         return (fields, values)
 
